/*******************************************************************************
* File Name: XP.c  
* Version 2.20
*
* Description:
*  This file contains APIs to set up the Pins component for low power modes.
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "XP.h"

static XP_BACKUP_STRUCT  XP_backup = {0u, 0u, 0u};


/*******************************************************************************
* Function Name: XP_Sleep
****************************************************************************//**
*
* \brief Stores the pin configuration and prepares the pin for entering chip 
*  deep-sleep/hibernate modes. This function applies only to SIO and USBIO pins.
*  It should not be called for GPIO or GPIO_OVT pins.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None 
*  
* \sideeffect
*  For SIO pins, this function configures the pin input threshold to CMOS and
*  drive level to Vddio. This is needed for SIO pins when in device 
*  deep-sleep/hibernate modes.
*
* \funcusage
*  \snippet XP_SUT.c usage_XP_Sleep_Wakeup
*******************************************************************************/
void XP_Sleep(void)
{
    #if defined(XP__PC)
        XP_backup.pcState = XP_PC;
    #else
        #if (CY_PSOC4_4200L)
            /* Save the regulator state and put the PHY into suspend mode */
            XP_backup.usbState = XP_CR1_REG;
            XP_USB_POWER_REG |= XP_USBIO_ENTER_SLEEP;
            XP_CR1_REG &= XP_USBIO_CR1_OFF;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(XP__SIO)
        XP_backup.sioState = XP_SIO_REG;
        /* SIO requires unregulated output buffer and single ended input buffer */
        XP_SIO_REG &= (uint32)(~XP_SIO_LPM_MASK);
    #endif  
}


/*******************************************************************************
* Function Name: XP_Wakeup
****************************************************************************//**
*
* \brief Restores the pin configuration that was saved during Pin_Sleep(). This 
* function applies only to SIO and USBIO pins. It should not be called for
* GPIO or GPIO_OVT pins.
*
* For USBIO pins, the wakeup is only triggered for falling edge interrupts.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None
*  
* \funcusage
*  Refer to XP_Sleep() for an example usage.
*******************************************************************************/
void XP_Wakeup(void)
{
    #if defined(XP__PC)
        XP_PC = XP_backup.pcState;
    #else
        #if (CY_PSOC4_4200L)
            /* Restore the regulator state and come out of suspend mode */
            XP_USB_POWER_REG &= XP_USBIO_EXIT_SLEEP_PH1;
            XP_CR1_REG = XP_backup.usbState;
            XP_USB_POWER_REG &= XP_USBIO_EXIT_SLEEP_PH2;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(XP__SIO)
        XP_SIO_REG = XP_backup.sioState;
    #endif
}


/* [] END OF FILE */
